//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yaku](index.md)/[toString](to-string.md)

# toString

[common]\
open override fun [toString](to-string.md)(): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)
